@@ -26,21 +26,11 @@
 
 import os
 import gtk
-import gettext
-import __builtin__
 
 share_files_dir= os.path.join("/usr","share/","nanny/client/gnome/admin/")
 ui_files_dir= os.path.join(share_files_dir,"ui/")
 icons_files_dir= os.path.join(share_files_dir,"icons/")
 
-__builtin__._ = gettext.gettext
-
-GETTEXT_DOMAIN = 'nanny'
-locale_dir = os.path.join("/usr", "share/" ,"locale/")
-
-gettext.bindtextdomain(GETTEXT_DOMAIN, locale_dir)
-gettext.textdomain(GETTEXT_DOMAIN)
-
 from AdminConsole import AdminConsole
 from ConfigureProxyDialog import ConfigureProxyDialog
 from ScheduleCalendar import ScheduleCalendar
